@@ -6,7 +6,7 @@ use strict;
 
 use Exporter;
 
-$Locale::Currency::Format::VERSION = '1.27';
+$Locale::Currency::Format::VERSION = '1.28';
 
 @Locale::Currency::Format::ISA     = qw(Exporter);
 @Locale::Currency::Format::EXPORT  = qw(
@@ -361,7 +361,7 @@ AMD => ["Armenian Dram",2,",",".","",$EMPTY,$EMPTY,"AMD",0],
 ANG => ["Antillian Guilder",2,".",","," ","\x{0192}","&#x0192;","NAf.",1],
 AON => ["New Kwanza",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 ARS => ["Argentine Peso",2,".",",","","\x{20B1}","&#x20B1;","\$",1],
-ATS => ["Schilling",2,".",","," ",$EMPTY,$EMPTY,"S",1],
+ATS => ["Schilling",2,".",","," ",$EMPTY,$EMPTY,"öS",1],
 AUD => ["Australian Dollar",2," ",".","","\x{0024}","&#x0024;","\$",1],
 AWG => ["Aruban Guilder",2,",","."," ","\x{0192}","&#x0192;","AWG",1],
 AZN => ["Azerbaijanian Manat",2,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,"m",$EMPTY],
@@ -387,10 +387,10 @@ CHF => ["Swiss Franc",2,"'","."," ",$EMPTY,$EMPTY,"SFr.",1],
 CLP => ["Chilean Peso",0,".","","","\x{20B1}","&#x20B1;","\$",1],
 CNY => ["Yuan Renminbi",2,",",".","","\x{5713}","&#x5713;","Y",1],
 COP => ["Colombian Peso",2,".",",","","\x{20B1}","&#x20B1;","\$",1],
-CRC => ["Costa Rican Colon",2,".",","," ","\x{20A1}","&#x20A1;","\x{20A1}",1],
+CRC => ["Costa Rican Colon",2,".",","," ","\x{20A1}","&#x20A1;","₡",1],
 CUP => ["Cuban Peso",2,",","."," ","\x{20B1}","&#x20B1;","\$",1],
 CVE => ["Cape Verde Escudo",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
-CYP => ["Cyprus Pound",2,".",",","","\x{00A3}","&#x00A3;","\x{00A3}",1],
+CYP => ["Cyprus Pound",2,".",",","","\x{00A3}","&#x00A3;","£",1],
 CZK => ["Czech Koruna",2,".",","," ",$EMPTY,$EMPTY,"Kc",0],
 DEM => ["Deutsche Mark",2,".",",","",$EMPTY,$EMPTY,"DM",0],
 DJF => ["Djibouti Franc",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
@@ -408,10 +408,10 @@ FIM => ["Markka",2," ",","," ",$EMPTY,$EMPTY,"mk",0],
 FJD => ["Fiji Dollar",0,$EMPTY,$EMPTY,"","\x{0024}","&#x0024;",$EMPTY,$EMPTY],
 FKP => ["Pound",0,$EMPTY,$EMPTY,"","\x{00A3}","&#x00A3;",$EMPTY,$EMPTY],
 FRF => ["French Franc",2," ",","," ","\x{20A3}","&#x20A3;","FRF",0],
-GBP => ["Pound Sterling",2,",",".","","\x{00A3}","&#x00A3;","",1],
+GBP => ["Pound Sterling",2,",",".","","\x{00A3}","&#x00A3;","£",1],
 GEL => ["Lari",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
-GHS => ["Cedi",2,",",".","","\x{20B5}","&#x20B5;","\x{20B5}",1],
-GIP => ["Gibraltar Pound",2,",",".","","\x{00A3}","&#x00A3;","",1],
+GHS => ["Cedi",2,",",".","","\x{20B5}","&#x20B5;","₵",1],
+GIP => ["Gibraltar Pound",2,",",".","","\x{00A3}","&#x00A3;","£",1],
 GMD => ["Dalasi",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 GNF => ["Guinea Franc",$EMPTY,$EMPTY,$EMPTY,$EMPTY,$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 GRD => ["Drachma",2,".",","," ","\x{20AF}","&#x20AF;","GRD",0],
@@ -424,7 +424,7 @@ HRK => ["Kuna",2,".",","," ",$EMPTY,$EMPTY,"kn",0],
 HTG => ["Gourde",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 HUF => ["Forint",0,".",""," ",$EMPTY,$EMPTY,"Ft",0],
 IDR => ["Rupiah",0,".","","",$EMPTY,$EMPTY,"Rp.",1],
-IEP => ["Irish Pound",2,",",".","","\x{00A3}","&#x00A3;","",1],
+IEP => ["Irish Pound",2,",",".","","\x{00A3}","&#x00A3;","£",1],
 ILS => ["New Israeli Sheqel",2,",","."," ","\x{20AA}","&#x20AA;","NIS",0],
 INR => ["Indian Rupee",2,",",".","","\x{20A8}","&#x20A8;","Rs.",1],
 IQD => ["Iraqi Dinar",3,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
@@ -433,7 +433,7 @@ ISK => ["Iceland Krona",2,".",","," ",$EMPTY,$EMPTY,"kr",0],
 ITL => ["Italian Lira",0,".",""," ","\x{20A4}","&#x20A4;","L.",1],
 JMD => ["Jamaican Dollar",2,",",".","","\x{0024}","&#x0024;","\$",1],
 JOD => ["Jordanian Dinar",3,",","."," ",$EMPTY,$EMPTY,"JD",1],
-JPY => ["Yen",0,",","","","\x{00A5}","&#x00A5;","",1],
+JPY => ["Yen",0,",","","","\x{00A5}","&#x00A5;","¥",1],
 KES => ["Kenyan Shilling",2,",",".","",$EMPTY,$EMPTY,"Kshs.",1],
 KGS => ["Som",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 KHR => ["Riel",2,$EMPTY,$EMPTY,"","\x{17DB}","&#x17DB;",$EMPTY,$EMPTY],
@@ -482,7 +482,7 @@ PHP => ["Philippine Peso",2,",",".","","\x{20B1}","&#x20B1;","PHP",1],
 PKR => ["Pakistan Rupee",2,",",".","","\x{20A8}","&#x20A8;","Rs.",1],
 PLN => ["Zloty",2," ",","," ",$EMPTY,$EMPTY,"zl",0],
 PTE => ["Portuguese Escudo",0,".",""," ",$EMPTY,$EMPTY,"Esc",0],
-PYG => ["Guarani",0,$EMPTY,$EMPTY,"","\x{20B2}","&#20B2;","Gs.",$EMPTY],
+PYG => ["Guarani",0,$EMPTY,$EMPTY,"","\x{20B2}","&#x20B2;","Gs.",$EMPTY],
 QAR => ["Qatari Rial",0,$EMPTY,$EMPTY,"","\x{FDFC}","&#xFDFC;",$EMPTY,$EMPTY],
 RON => ["Leu",2,".",","," ",$EMPTY,$EMPTY,"lei",0],
 RSD => ["Serbian Dinar",2,$EMPTY,$EMPTY,$EMPTY,$EMPTY,$EMPTY,"din",0],
@@ -503,7 +503,7 @@ SLL => ["Leone",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 SOS => ["Somali Shilling",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 SRG => ["Surinam Guilder",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 STD => ["Dobra",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
-SVC => ["El Salvador Colon",2,",",".","","\x{20A1}","&#x20A1;","\x{20A1}",1],
+SVC => ["El Salvador Colon",2,",",".","","\x{20A1}","&#x20A1;","¢",1],
 SYP => ["Syrian Pound",0,$EMPTY,$EMPTY,"","\x{00A3}","&#x00A3;",$EMPTY,$EMPTY],
 SZL => ["Lilangeni",2,"",".","",$EMPTY,$EMPTY,"E",1],
 THB => ["Baht",2,",","."," ","\x{0E3F}","&#x0E3F;","Bt",0],
